@@ -30,8 +30,8 @@ from autologging import logged
 
 from . import Packet
 from ..bytes_ import unpack_uint, unpack_usint, unpack_dint, UNPACK_DATA_FUNCTION
-from ..const import (SUCCESS, INSUFFICIENT_PACKETS, TAG_SERVICES_REPLY,
-                     get_service_status, get_extended_status, MULTI_PACKET_SERVICES, REPLY_START, STRUCTURE_READ_REPLY,
+from ..const import (SUCCESS, INSUFFICIENT_PACKETS, TAG_SERVICES_REPLY, SERVICE_STATUS,EXTEND_CODES,
+                     MULTI_PACKET_SERVICES, REPLY_START, STRUCTURE_READ_REPLY,
                      DATA_TYPE, DATA_TYPE_SIZE)
 
 
@@ -402,3 +402,34 @@ def dword_to_bool_array(dword):
     return bools
 
 
+def get_service_status(status):
+    return SERVICE_STATUS.get(status, f'Unknown Error ({status:0>2x})')
+
+
+def get_extended_status(msg, start):
+    status = unpack_usint(msg[start:start + 1])
+    # send_rr_data
+    # 42 General Status
+    # 43 Size of additional status
+    # 44..n additional status
+
+    # send_unit_data
+    # 48 General Status
+    # 49 Size of additional status
+    # 50..n additional status
+    extended_status_size = (unpack_usint(msg[start + 1:start + 2])) * 2
+    extended_status = 0
+    if extended_status_size != 0:
+        # There is an additional status
+        if extended_status_size == 1:
+            extended_status = unpack_usint(msg[start + 2:start + 3])
+        elif extended_status_size == 2:
+            extended_status = unpack_uint(msg[start + 2:start + 4])
+        elif extended_status_size == 4:
+            extended_status = unpack_dint(msg[start + 2:start + 6])
+        else:
+            return 'Extended Status Size Unknown'
+    try:
+        return f'{EXTEND_CODES[status][extended_status]}  ({status:0>2x}, {extended_status:0>2x})'
+    except LookupError:
+        return "Extended status info not present"
\ No newline at end of file
